==> haskell-tagged-0.8.6.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagged
version:              0.8.6.1
visibility:           public
id:                   tagged-0.8.6.1-FL843C40q4d1DeuwYADr25
key:                  tagged-0.8.6.1-FL843C40q4d1DeuwYADr25
license:              BSD-3-Clause
copyright:            2009-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/tagged
synopsis:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments

description:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments.

category:             Data, Phantom Types
abi:                  2b62c870e5905106b2ec4cb10b1c62af
exposed:              True
exposed-modules:      Data.Proxy.TH Data.Tagged
import-dirs:          /usr/lib/ghc-9.0.1/site-local/tagged-0.8.6.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/tagged-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/tagged-0.8.6.1
hs-libraries:         HStagged-0.8.6.1-FL843C40q4d1DeuwYADr25
depends:
    base-4.15.0.0 deepseq-1.4.5.0 template-haskell-2.17.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tagged/html/tagged.haddock
haddock-html:         /usr/share/doc/haskell-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagged-0.8.6.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagged
version:              0.8.6.1
visibility:           public
id:                   tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR
key:                  tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR
license:              BSD-3-Clause
copyright:            2009-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/tagged
synopsis:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments

description:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments.

category:             Data, Phantom Types
abi:                  182ccb5fbdd35335701e468d4fde2e5f
exposed:              True
exposed-modules:      Data.Proxy.TH Data.Tagged
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tagged-0.8.6.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tagged-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/tagged-0.8.6.1
hs-libraries:         HStagged-0.8.6.1-79gYUUazit6EfoPS33FHdR
depends:
    base-4.15.1.0 deepseq-1.4.5.0 template-haskell-2.17.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tagged/html/tagged.haddock
haddock-html:         /usr/share/doc/haskell-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
